#!/usr/bin/perl
#
#	Compile the max cscore for the gene with mean exp >= 0.5
#

use strict;
use Getopt::Long;

my ( $c_file, $info_file, $pgroup_file, $outfile );

my $usage = "\n" . "Usage:\n\tperl " . $0 . "-cscore all_v_all_cscore_b1.csv -gene_info gene_dep_exp.info.txt -pgroup paralog_group.txt -out all_v_all_maxCscore_dep_exp.info.txt";

GetOptions(
	'c|cscore|c_file=s' => \$c_file,
	'gene|gene_info=s'  => \$info_file,
	'pgroup=s'			=> \$pgroup_file,
	'o|out|outfile=s'   => \$outfile,
) or die $usage;


my %pgroup;

open( PGROUP, $pgroup_file ) or die "Can't open $pgroup_file";
while( <PGROUP> ) {
	$_ =~ s/^\s+|\s+$//g;

	my @line = split "\t", $_;

	my @genes = split ",", $line[1];

	foreach my $g ( @genes ) {
		$pgroup{$g} = $line[0];
	}
}
close PGROUP;

my ( %info, %exp );

open( INFO, $info_file ) or die "Can't open $info_file";
my $head = <INFO>;
while( <INFO> ) {
	$_ =~ s/^\s+|\s+$//g;

	my @line = split "\t", $_;

	my ( $gene, $dep_mean, $dep_sd, $exp_mean, $exp_sd, $pearson, $c, $paraNum, $tau, $ppi ) = split "\t", $_;

	$info{$gene} = $paraNum."\t".$dep_mean."\t".$exp_mean."\t".$tau."\t".$ppi;

	$exp{$gene} = $exp_mean;
}
close INFO;

open( OUT, ">$outfile" ) or die "Can't write to $outfile";

my @header = ( "gene1", "gene2", "cscore", "paralogous",
	"G1_paralog_num","G1_dep_mean", "G1_exp_mean", "G1_tau", "G1_PPI",
	"G2_paralog_num","G2_dep_mean", "G2_exp_mean", "G2_tau", "G2_PPI" );

print OUT join( "\t", @header )."\n";

open( CFILE, $c_file ) or die "Can't open $c_file";
my $head = <CFILE>;
$head =~ s/^\s+|\s+$//g;
$head =~ s/\./-/g;
my @g2 = split ",", $head;


while( <CFILE> ) {
	$_ =~ s/^\s+|\s+$//g;

	my @line = split ",", $_;

	my $g1 = $line[0];
	$g1 =~ s/\./-/g;

	my $maxC = -1000;
	my $g2_sel = "";

	my $index = 0;

	for( my $i = 1; $i < @line; $i++ ) {
		if ( $exp{$g2[$i]} < 0.5 ) {
			next;
		}
		if ( $g2[$i] eq $g1 ) {
			next;
		}
		if ( $line[$i] > $maxC ) {
			$maxC = $line[$i];
			$g2_sel = $g2[$i];
			$index = $i;
		}
	}

#	print STDERR $g1."\t".$g2_sel."\t".$index."\t".$maxC."\n";

	my $paralogous = 0;
	if ( $pgroup{$g1} == $pgroup{$g2_sel} ) {
		$paralogous = 1;
	}

	if ( length $g2_sel > 0 ) {
		my @println = ( $g1, $g2_sel, $maxC, $paralogous, $info{$g1}, $info{$g2_sel} );

		print OUT join( "\t", @println )."\n";
	}
}

close CFILE;
