library(ggplot2)
library(plyr)

d <- read.table("cscore_1sd_dep_exp.csv", header=T, sep=',')
all <- read.table("gene_dep_exp.info.txt", header=T, sep='\t')

d$Cscore_bin = round_any( d$Cscore+0.05, 0.1, floor )-0.05
d[d$Cscore_bin>0.45, ]$Cscore_bin = 0.45

all <- all[all$DS_mean < 0, ]
all <- all[all$Expr_mean > 0.5, ]

len <- dim(all)[1]
all.mutate <- data.frame( all$Gene, all$Gene, rep("All",len), rep("NaN", len), all$DS_mean, all$DS_sd, all$Expr_mean, all$Expr_sd, all$DS_mean, all$DS_sd, all$Expr_mean, all$Expr_sd, rep("All",len) )
colnames(all.mutate) = colnames(d)

d <- rbind(d, all.mutate)

d$Cscore_bin <- factor(d$Cscore_bin, c("All", "0.25", "0.35", "0.45") )


t.test(d[d$Cscore_bin == 0.25, ]$G1_DS_mean, d[d$Cscore_bin == 0.25 & df$group =="rand_ctrl", ]$Cscore, alternative="less", na.rm=T)

fig<-ggplot( d,  aes(x=Cscore_bin, y=G1_DS_mean, group=Cscore_bin ) ) + 
	geom_violin( fill='blue1', color=NA, alpha=0.25, adjust=2) +
	geom_boxplot( fill='royalblue2', width=0.1, outlier.shape=NA ) +
	scale_x_discrete( labels=c("All", "0.25-0.35", "0.35-0.45", "\u2265 0.45", "0.55")) +
	labs( x='C-score', y = 'G1 DS mean' ) +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position = "none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
fig
ggsave( "D:/Cscore/Cscore_mean_sd_ctrl/Cscore_ds_mean.svg", fig, device='svg', height=7, width=8)

fig<-ggplot( d,  aes(x=Cscore_bin, y=G2_Expr_mean, group=Cscore_bin ) ) + 
	geom_violin( fill='red', color=NA, alpha=0.25, adjust=2) +
	geom_boxplot( fill='red', width=0.1, outlier.shape=NA ) +
	scale_x_discrete( labels=c("All", "0.25-0.35", "0.35-0.45", "\u2265 0.45")) +
	labs( x='C-score', y = 'G2 Expr mean' ) +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position = "none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
fig
ggsave( "D:/Cscore/Cscore_mean_sd_ctrl/Cscore_exp_mean.svg", fig, device='svg', height=7, width=8)



### Mean Control ####

d <- read.table("cscore_1sd_info.csv", header=T, sep=',')

all <- read.table("gene_dep_exp.info.txt", header=T, sep='\t')

d[d$Cscore_bin>0.45, ]$Cscore_bin = 0.45

all <- all[all$DS_mean < 0, ]
all <- all[all$Expr_mean > 0.5, ]

len <- dim(all)[1]
all.mutate <- data.frame( all$Gene, all$Expr_sd, rep("All", len), rep("All",len), rep("All",len) )
colnames(all.mutate) <- c("gene", "sd", "Cscore", "Cscore_bin", "group")

for ( i in seq(1,5,1) ) {
	print(i)
	ctrl <- read.table(paste0("D:/Cscore/Cscore_mean_sd_ctrl/exp_mean_rand_ctrl_",i,".csv"), header=T, sep=',')
	
	ctrl[ctrl$Cscore_bin>0.45, ]$Cscore_bin = 0.45
	
	ctrl <- cbind(ctrl, rep("rand_ctrl", time=length(ctrl$gene)))
	colnames(ctrl) <- c("gene", "sd", "Cscore", "Cscore_bin", "group")

	df <- data.frame( d$G2, d$G2_Expr_sd, d$Cscore, d$Cscore_bin, rep("actual", times=length(d$Cscore) ) )
	colnames(df) <- c("gene", "sd",  "Cscore", "Cscore_bin", "group")
	
	df <- rbind(df, ctrl, all.mutate)
	
#	df <- rbind(df, all.mutate)
	
	t.test(df[df$Cscore_bin == 0.25 & df$group=="actual", ]$Cscore, df[df$Cscore_bin == 0.25 & df$group =="rand_ctrl", ]$Cscore, alternative="less", na.rm=T)
	
	df$Cscore_bin <- factor(df$Cscore_bin, c("All", "0.25", "0.35", "0.45") )
	
	fig <- ggplot( df, aes(x=as.factor(Cscore_bin), y=sd, fill=df$group )) +
		geom_boxplot(width=0.1, outlier.shape=NA, position=position_dodge(1)) +
		geom_violin( color=NA, alpha=0.25, adjust=2, position=position_dodge(1) ) +
		scale_x_discrete( labels=c("All", "0.25-0.35", "0.35-0.45", "\u2265 0.45")) +
		labs( x='C-score', y = 'G2 Expression SD' ) +
		theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position = "none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
	fig
	
#	ggsave( paste0("D:/Cscore/Cscore_mean_sd_ctrl/Cscore_exp_mean_sd_rand_ctrl_",i,".svg"), fig, device='svg', height=7, width=8)
}

#### stack ####

cscore0.25Num = c(1, 8213, 32274, 24051, 7349)
total_num = c(502349,	101827500,	19591611,	2443860,	488772)

dep_sd <- data.frame( interval = c("0-0.1", "0.1-0.2", "0.2-0.3", "0.3-0.4", "0.4", "0-0.1", "0.1-0.2", "0.2-0.3", "0.3-0.4", "0.4"),
																						cscoreNum = c( (total_num-cscore0.25Num)/total_num, cscore0.25Num/total_num),
																						cscore = c( rep("C-score>0.25", times=5), rep("C-score<=0.25", times=5)) )
																						
fig<-ggplot( dep_sd, aes( x=interval, y=cscoreNum, fill=cscore) ) +
	geom_col(position="stack", width=0.7) +
	scale_fill_manual(values = c("#EFC000FF", "#0073C2FF")) +
	labs( x='DS SD interval', y = 'Proportion' ) +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "black"), legend.position = "none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
fig
ggsave( paste0("D:/Cscore/Cscore_mean_sd_ctrl/Cscore_dep_sd_proportion.svg"), fig, device='svg', height=7, width=8)

dep_sd <- data.frame( interval=rep("0.4", time=4),
																						cscoreNum=c(5410, 1855, 79, 5),
																						cscore=c(0.25))















fig<-ggplot( d, aes(x=as.factor(round(G1_DS_sd,1)), y=Cscore, group=as.factor(round(G1_DS_sd,1)))) +
	geom_boxplot( fill='red', width=0.1, outlier.shape=NA) +
	geom_violin( fill='red', color=NA, alpha=0.25, trim=TRUE ) +
	scale_y_continuous(limits=c(0.25, 0.5)) +
	labs( x='G1 DS Sd', y = 'Cscore' ) +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position = "none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
fig
ggsave( "D:/Cscore/Cscore_mean_sd_ctrl/DS_sd_w_Cscore.svg", fig, device='svg', height=7, width=8)


fig<-ggplot( d, aes(x=as.factor(round(G2_Expr_sd)), y=Cscore, group=as.factor(round(G2_Expr_sd)))) +
	geom_boxplot( fill='blue', width=0.1, outlier.shape=NA) +
	geom_violin( fill='blue', color=NA, alpha=0.25, trim=TRUE ) +
	scale_y_continuous(limits=c(0.25, 0.5)) +
	labs( x='G2 Expr Sd', y = 'Cscore' ) +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position = "none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
fig
ggsave( "D:/Cscore/Cscore_mean_sd_ctrl/Expr_sd_w_Cscore.svg", fig, device='svg', height=7, width=8)


ggplot( d, aes(x=G1_DS_mean, y=Cscore) ) + geom_point()

ggplot( d, aes(x=G1_DS_sd, y=Cscore) ) + geom_point()

ggplot( d, aes(x=G2_Expr_mean, y=Cscore) ) + geom_point()

ggplot( d, aes(x=G2_Expr_sd, y=Cscore) ) + geom_point()
