#!/usr/bin/env python
# coding: utf-8

# In[887]:


import sys
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
import random
import scipy


# ### load gene symbol xref

# In[320]:


hgnc = pd.read_csv('/data/home/N417/Jen-Hao/Genelists_data/HGNC/20211116_HGNC_curr-prevSymbols.txt', sep='\t', header=0, index_col=0)


# ### load paralog file

# In[3]:


paralog = pd.read_pickle('/data/home/N417/Jen-Hao/Paralog/paralog_family.pkl')


# In[5]:


paralog


# ### load gene location

# In[330]:


### use Gene name col=5 as index
gpos = pd.read_csv('/data1/home/N417/Jen-Hao/Genelists_data/Gene_position/ENSEMBLv97_codingGene_geneStart-End.tsv', sep='\t', index_col=2, header=0)


# In[333]:


# drop rows without Gene Name
gpos = gpos[~pd.isna(gpos.index)]


# In[334]:


# keep the gene name with the larger Gene Stable ID if gene name is duplicated
gpos.sort_values(by='Gene stable ID', inplace=True)
gpos = gpos[~gpos.index.duplicated(keep='last')]


# In[470]:


if 'AC118549.1' in gpos.index:
    print('yes')


# ### load cscore file

# In[893]:


cscore = pd.read_csv('/data/home/N417/Jen-Hao/Cscore/cscore_1sd_info.csv', header=0)


# In[437]:


cscore


# ### find minimum distance of paralog of G1 to G2 or Random Gene

# In[259]:


# output header
# G1, G1_paralog, G1p_chr, G1p_start, G1p_end, G2, G2_chr, G2_start, G2_end, chrMatch, start-start, start-end, end-start, end-end, min-diff


# In[950]:


cscore2 = cscore


# In[989]:


g2_g1p_list, r_g1p_list = [], []
g2_mindist_list, r_mindist_list = [], []
rand_gene = []
unmatched_g2 = set()

for i in cscore.index:
    g1 = cscore.at[i, 'G1']
    
    ### retrieve g2 genomic position
    g2 = cscore.at[i, 'G2']

    if g2 in gpos.index:
        g2chr = gpos.at[g2, 'Chromosome/scaffold name']
        g2s = gpos.at[g2, 'Gene start (bp)']
        g2e = gpos.at[g2, 'Gene end (bp)']
    else:
        unmatched_g2.add(g2)
        g2chr, g2s, g2e = 'NA', 'NA', 'NA'
    
    ### retrieve random gene and its genomic position
    rg = g1
    while rg == g1:
        rind = random.randint(0, len(gpos.index)-1)
        rg = gpos.index[rind]
    
    rchr = gpos.at[rg, 'Chromosome/scaffold name']
    rs = gpos.at[rg, 'Gene start (bp)']
    re = gpos.at[rg, 'Gene end (bp)'] 

    ### find the paralog with minimum distance
    g2_g1p, r_g1p = 'NA', 'NA'
    
    para = paralog[paralog[g1] == 1].index.to_list()
    plen = len(para)
    
    g2_mindist, r_mindist = float('inf'), float('inf')
    
    for p in para:
        if p not in gpos.index:
            continue
        
        pchr = gpos.at[p, 'Chromosome/scaffold name']
        ps = gpos.at[p, 'Gene start (bp)']
        pe = gpos.at[p, 'Gene end (bp)']
        
        if g2 not in para and g2 in gpos.index:
            if pchr == g2chr:
                g2_dist = min(abs(g2s-ps), abs(g2s-pe), abs(g2e-ps), abs(g2e-pe))
                if g2_dist < g2_mindist:
                    g2_mindist = g2_dist
                    g2_g1p = p
        
        if rg not in para:
            if pchr == rchr:
                r_dist = min(abs(rs-ps), abs(rs-pe), abs(re-ps), abs(re-pe))
                if r_dist < r_mindist:
                    r_mindist = r_dist
                    r_g1p = p
            
    if g2_mindist == float('inf'):
        g2_mindist = 'NA'
    if r_mindist == float('inf'):
        r_mindist = 'NA'
    
    g2_g1p_list.append(g2_g1p)
    r_g1p_list.append(r_g1p)
    g2_mindist_list.append(g2_mindist)
    r_mindist_list.append(r_mindist)
    rand_gene.append(rg)
    
    if i % 5000 == 0:
        print(i)


cscore['G2_G1P'] = g2_g1p_list
cscore['G2_mindist'] = g2_mindist_list
cscore['Rand_gene'] = rand_gene
cscore['R_G1P'] = r_g1p_list
cscore['R_mindist'] = r_mindist_list

print(unmatched_g2)


# ### calculate expression correlation

# In[ ]:


exp = pd.read_pickle('/data/home/N417/Jen-Hao/DepMap/CCLE_expression/cor_all_exp_all_exp.pkl')


# In[969]:


g2_g1p_cor, r_g1p_cor = [], []
for i in cscore.index:
    g2 = cscore.at[i, 'G2']
    g2_g1p = cscore.at[i, 'G2_G1P']
    rg = cscore.at[i, 'Rand_gene']
    r_g1p = cscore.at[i, 'R_G1P']
    
    if g2 in exp.index and g2_g1p in exp.index:
        g2_g1p_cor.append(exp.at[g2, g2_g1p])
    else:
        g2_g1p_cor.append('NA')
        
    if rg in exp.index and r_g1p in exp.index:
        r_g1p_cor.append(exp.at[rg, r_g1p])
    else:
        r_g1p_cor.append('NA')
        
cscore['G2_G1P_expCor'] = g2_g1p_cor  
cscore['R_G1P_expCor'] = r_g1p_cor  


# In[941]:


cscore[cscore['G1'] == 'ARHGEF7']


# In[971]:


cscore.to_csv("/data/home/N417/Jen-Hao/Cscore/cscore_1sd_info_Dist.csv", sep=',', index=False, header=True)

