library(ggplot2)
library(dplyr)


df = read.table('cscore_1sd_info_Dist.csv', header=T, sep=',')
df$Cscore_bin5 = as.factor(df$Cscore_bin5)

## rearrange table for distance plot
g2 = df[!is.na(df$G2_G1P),]

# for calculating cutoffs
g2.dist = data.frame()
for (c in seq(0.25,0.45, 0.05)) {
	g2 = df[!is.na(df$G2_G1P) & df$Cscore > c,]
	new.dist = data.frame(G1 = g2$G1,
																					pairG = g2$G2,
																					G1P = g2$G2_G1P,
																					Dist = g2$G2_mindist,
																					Cscore = g2$Cscore,
																					#Cscore_bin = round(g2$Cscore/5,2)*5,
																					Cscore_bin = c,
																					bin = 'G2 to G1P')
	g2.dist = rbind(g2.dist, new.dist)
}

g2 = df[!is.na(df$G2_G1P),]
g2.dist = data.frame(G1 = g2$G1,
																						pairG = g2$G2,
																						G1P = g2$G2_G1P,
																						Dist = g2$G2_mindist,
																						Cscore = g2$Cscore,
																						Cscore_bin = round(g2$Cscore/5,2)*5,
																						#Cscore_bin = c,
																						bin = 'G2 to G1P')


g2.dist[g2.dist$Cscore_bin > 0.45,]$Cscore_bin = 0.45
g2.dist$Cscore_bin = as.factor(g2.dist$Cscore_bin)

fig <- ggplot(g2.dist, aes(as.factor(Cscore_bin), Dist, fill=bin)) +
	stat_ydensity( color=NA, alpha=0.25, adjust=3, trim=T) +
	geom_boxplot(width=0.1, outlier.size = 0.5) +
	geom_hline(yintercept = 2500000, size=0.5, color='grey40', linetype=1) +
	scale_y_continuous(trans='log10', limits=c(10^2, 10^9), breaks=c(10^2, 10^4,10^6,10^8)) +
	labs( x='C-score cutoff', y='Distance (bp)') +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"), legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black") )
fig


ggsave( filename="Cscore_G1PDist/G2-G1P_Rand_dist.boxplot.svg", plot=fig, device="svg", height=7, width=7 )