#!/usr/bin/perl
#
#	Compile paralogs into groups
#

use strict;

my ( $para_file, $outfile );

my $usage = "\n" . "Usage:\n\tperl " . $0 . "-paralog ensembl_paralog_all.txt -out paralog_group.txt";

GetOptions(
	'p|para|paralog=s'	=> \$para_file,
	'o|out|outfile=s'	=> \$outfile,
) or die $usage;

my %lexOrder;

open( PARA, $para_file ) or die "Can't open $para_file";
<PARA>;
while( <PARA> ) {
	$_ =~ s/^\s+|\s+$//g;

	my @line = split "\t", $_;

	my $g1 = $line[0];
	my $g2 = $line[2];

	if ( length $g2 < 1 ) {
		next;
	}

	if ( $g1 le $g2 ) {
		$lexOrder{$g1}{$g2} = 1;
	} elsif ( $g1 gt $g2 ) {
		$lexOrder{$g2}{$g1} = 1;
	}
}
close PARA;

my %group;
my $counter = 0;
my %geneXgrp;

foreach my $g1 ( sort keys %lexOrder ) {
	if ( exists $geneXgrp{$g1} ) {
		foreach my $g2 ( keys %{$lexOrder{$g1}} ) {
			$group{$geneXgrp{$g1}}{$g2} = 1;
			$geneXgrp{$g2} = $geneXgrp{$g1};
		}
	} else {
		my $newGrp = 1;
		foreach my $g2 ( sort keys %{$lexOrder{$g1}} ) {
			if ( exists $geneXgrp{$g2} ) {
				$newGrp = 0;
				$group{$geneXgrp{$g2}}{$g1} = 1;
				$geneXgrp{$g1} = $geneXgrp{$g2};
				foreach my $g2_add ( keys %{$lexOrder{$g1}} ) {
					$group{$geneXgrp{$g2}}{$g2_add} = 1;
					$geneXgrp{$g2_add} = $geneXgrp{$g2};
				}
				last;
			}
		}
		if ( $newGrp ) {
			$counter++;
			$group{$counter}{$g1} = 1;
			$geneXgrp{$g1} = $counter;
			foreach my $g2 ( keys %{$lexOrder{$g1}} ) {
				$group{$counter}{$g2} = 1;
				$geneXgrp{$g2} = $counter;
			}
		}
	}
}

open( OUT, ">$outfile" ) or die "Can't wirte to $outilfe";

foreach my $gnum ( sort { $a <=> $b } keys %group ) {
	print OUT $gnum."\t";
	my @print_group;
	foreach my $g ( sort keys %{$group{$gnum}} ) {
		push( @print_group, $g );
	}
	print OUT join( ",", @print_group )."\n";
}

close OUT;
