#!/usr/bin/perl
#
#	Process PPI data from STRING to have one protein with number of interacting partners
#

use strict;

my $ppi_file  = $ARGV[0]; # /home2/test12/JenHao/PPI/9606.protein.links.v11.0.txt
my $info_file = $ARGV[1]; # 9606.protein.info.v11.0.txt

my ( %enspXgs, %gsXensp );

open( INFO, $info_file ) or die "Can't open $info_file";
<INFO>;
while( <INFO> ) {
	$_ =~ s/^\s+|\s+$//g;

	my @line = split "\t", $_;

	$enspXgs{$line[0]} = $line[1];
	$gsXensp{$line[1]} = $line[0];
}
close INFO;

my %ppi;

open( PPI, $ppi_file ) or die "Can't open $ppi_file";
<PPI>;
while( <PPI> ) {
	$_ =~ s/^\s+|\s+$//g;

	my @line = split " ", $_;

	my ( $p1 ) = $line[0];
	my ( $p2 ) = $line[1];
	my $score = $line[2];

	my ( $g1, $g2 );
	if ( exists $enspXgs{$p1} ) {
		$g1 = $enspXgs{$p1};
	}
	if ( exists $enspXgs{$p2} ) {
		$g2 = $enspXgs{$p2};
	}

	if ( !defined $g1 or !defined $g2 ) {
		next;
	}

	$ppi{$g1}{$g2} = $score;
}
close PPI;

print "Gene\tENSP\tPPI\tParnters\n";

foreach my $g1 ( keys %ppi ) {
	print $g1."\t".$gsXensp{$g1}."\t".keys( $ppi{$g1} )."\t";

	my @arr;
	foreach my $g2 ( keys %{$ppi{$g1}} )  {
		push( @arr, $g2 );
	}

	print join( ",", @arr )."\n";
}
