library(ggplot2)
library(ggrepel)
library(dplyr)


#### Fig 5d dep exp scatter ####

gg1 = "FAM50A"
gg2 = "FAM50B"

g1 <- read.table(paste0("all_genes/",gg1,"_ds_expr.txt"),header=T,sep="\t",na.string="NA")
g2 <- read.table(paste0("all_genes/",gg2,"_ds_expr.txt"),header=T,sep="\t",na.string="NA")
xref <- read.table("Experiment_data/CCLE_expr_cellline_xref.txt",header=T,sep="\t")

dep <- g1$DS
exp <- g2$Expr

m <- lm(exp~dep)

d <- data.frame(cell= g1$Cell, dep=g1$DS, exp=g2$Expr)

select <- as.vector(xref$depmap)

c <- cor.test(dep,exp)

d1 <- d[d$cell %in% select,]
d2 <- d[!(d$cell %in% select), ]

cscore <- c$estimate * (1+7.48E-2/m$coefficients[2])

print(c$estimate)
print(m$coefficients[2])
print(cscore)

d1mod <-d1 %>%
	inner_join(xref, by = c("cell" = "depmap")) %>%
	select(cell = CCLE, dep, exp) %>%
	mutate(cell = as.factor(cell))

fig<-ggplot(d1mod, aes(x=d1mod$dep, y=d1mod$exp)) + geom_point(color="red") +
#	geom_point(data=d2, aes(x=d2$dep, y=d2$exp), pch=16, color="black", size=4, alpha=0.5) +
	geom_point(data=d2, aes(x=d2$dep, y=d2$exp)) +
	geom_point(data=d1mod, aes(x=d1mod$dep, y=d1mod$exp), pch=16, color="red", size=4) +
	geom_smooth(data=d2, aes(x=d2$dep, y=d2$exp), method="lm", fullrange=T, se=F, show.legend=F, color="red", size=2) +
	geom_label_repel(aes(label=d1mod$cell), size=7, color="red") +
	labs(x=expression(paste(italic("FAM50B"), " (D.S.)")), y=expression(paste(italic("FAM50B"), " (log"[2],"TPM)")) ) +
	scale_x_continuous(limits=c(-2.5,0), breaks=seq(-2,0,1) ) +
	scale_y_continuous(limits=c(0,8), position="right", expand=c(0,0)) + 
	#scale_y_continuous(position="right") +
	coord_cartesian(clip = "off") + 
	theme(panel.background = element_blank(), axis.text=element_text(size=20, color="black"), text=element_text(size=25), 
							axis.line = element_line(colour = "black"), legend.position = "none")

fig
ggsave(filename=paste0("Cscore_experiment/Fig_",gg1,"_",gg2,".scatter.svg"), plot=fig, device="svg", height=7, width=7)



d <- read.table("Experiment_data/ID_78040_N416-FSH.mod.forR.txt",sep="\t", header=T)

cell = "LN18"



ctrl <- data.frame(type="Control", mean=mean(d[d$Type=="Control", ]$Cell.count), sd=sd(d[d$Type=="Control", ]$Cell.count) )

d <- cbind( d, d$Cell.count/ctrl$mean)
colnames(d) <- c( "Type", "Well", "Cell.count", "Norm.count" )

type <- c( "Control", "POP7", "RPP25", "POP7+RPP25")
pval <- data.frame()

for ( i in seq(1,length(type),1) ) {
	
	pval.list = c()
	
	for ( j in seq(1,length(type),1) ){
		p <- t.test(d[d$Type==type[i], ]$Norm.count, d[d$Type==type[j], ]$Norm.count, alternative="greater")
		
		pval.list <- c(pval.list, p$p.value)
	}
	
	pval <- rbind( pval, pval.list) 
}

x.lab = type
colnames(pval) <- x.lab
rownames(pval) <- x.lab

write.table(pval, file=paste0("Cscore_experiment/RelCellGrowth_pval_",cell,".csv"),sep=",",col.names=NA)


data <- data.frame()
r1 <- data.frame(type="Control", mean=mean(d[d$Type=="Control", ]$Norm.count), sd=sd(d[d$Type=="Control", ]$Norm.count) )
r2 <- data.frame(type="POP7", mean=mean(d[d$Type=="POP7", ]$Norm.count), sd=sd(d[d$Type=="POP7", ]$Norm.count) )
r3 <- data.frame(type="RPP25", mean=mean(d[d$Type=="RPP25", ]$Norm.count), sd=sd(d[d$Type=="RPP25", ]$Norm.count) )
r4 <- data.frame(type="POP7+RPP25", mean=mean(d[d$Type=="POP7+RPP25", ]$Norm.count), sd=sd(d[d$Type=="POP7+RPP25", ]$Norm.count) )

data<-rbind(data, r1, r2, r3, r4)

data$type.reorder <- factor( data$type, c("Control", "POP7", "RPP25", "POP7+RPP25"))

fig<- ggplot(data, aes(x=type.reorder, y=mean)) +
	geom_bar(stat="identity") +
	geom_errorbar(aes(ymin=mean-sd, ymax=mean+sd), width =0.5, position=position_dodge(0.9)) + 
	scale_y_continuous(expand=c(0,0), limits=c(0,1.1))+
	labs(x=NULL, y="Cell Count", title=cell) +
	theme(panel.background = element_blank(), axis.line = element_line(colour = "black"),
							axis.text=element_text(size=20), text=element_text(size=25, color="black") ) 

fig
ggsave(filename=paste0("Cscore_experiment/RelCellGrowth_",cell,".mod.barplot.svg"), plot=fig, device="svg", height=7, width=7)






d <- read.table("Experiment_data/0910_POP7-RPP25_72hr_U2OS.txt",sep="\t", header=T)

cell = "U2OS"



ctrl <- data.frame(type="Control", mean=mean(d[d$condition=="Control", ]$fold), sd=sd(d[d$condition=="Control", ]$fold) )

d <- cbind( d, d$fold/ctrl$mean)
colnames(d) <- c( "condition", "fold", "Norm.fold" )

type <- c( "Control", "POP7", "RPP25", "POP7+RPP25")
pval <- data.frame()

for ( i in seq(1,length(type),1) ) {
	
	pval.list = c()
	
	for ( j in seq(1,length(type),1) ){
		p <- t.test(d[d$condition==type[i], ]$Norm.fold, d[d$condition==type[j], ]$Norm.fold, alternative="greater")
		
		pval.list <- c(pval.list, p$p.value)
	}
	
	pval <- rbind( pval, pval.list) 
}
x.lab=type
colnames(pval) <- x.lab
rownames(pval) <- x.lab

write.table(pval, file=paste0("Cscore_experiment/RelConf_pval_POP7-RPP25_",cell,".csv"),sep=",",col.names=NA)


data <- data.frame()
r1 <- data.frame(type="Control", mean=mean(d[d$condition=="Control", ]$Norm.fold), sd=sd(d[d$condition=="Control", ]$Norm.fold) )
r2 <- data.frame(type="POP7", mean=mean(d[d$condition=="POP7", ]$Norm.fold), sd=sd(d[d$condition=="POP7", ]$Norm.fold) )
r3 <- data.frame(type="RPP25", mean=mean(d[d$condition=="RPP25", ]$Norm.fold), sd=sd(d[d$condition=="RPP25", ]$Norm.fold) )
r4 <- data.frame(type="POP7+RPP25", mean=mean(d[d$condition=="POP7+RPP25", ]$Norm.fold), sd=sd(d[d$condition=="POP7+RPP25", ]$Norm.fold) )

data<-rbind(data, r1, r2, r3, r4)

data$type.reorder <- factor( data$type, c( "Control", "POP7", "RPP25", "POP7+RPP25") )

fig<- ggplot(data, aes(x=type.reorder, y=mean)) +
	geom_bar(stat="identity") +
	geom_errorbar(aes(ymin=mean-sd, ymax=mean+sd), width =0.5, position=position_dodge(0.9)) + 
	scale_y_continuous(expand=c(0,0), limits=c(0,1.1))+
	labs(x=NULL, y="Relative cell growth", title=cell) +
	theme(panel.background = element_blank(), axis.line = element_line(colour = "black"),
							axis.text=element_text(size=20), text=element_text(size=25, color="black") ) 

fig
ggsave(filename=paste0("Cscore_experiment/RelConf_POP7-RPP25_72hr_",cell,".mod.barplot.svg"), plot=fig, device="svg", height=7, width=5)






d <- read.table("Experiment_data/0914_FAM50A-FAM50B_96hr_MCF7.txt",sep="\t", header=T)

cell = "MCF7"

ctrl <- data.frame(type="Control", mean=mean(d[d$condition=="Control", ]$fold), sd=sd(d[d$condition=="Control", ]$fold) )

d <- cbind( d, d$fold/ctrl$mean)
colnames(d) <- c( "condition", "fold", "Norm.fold" )

type <- c( "Control", "FAM50A", "FAM50B", "FAM50A+FAM50B")
pval <- data.frame()

for ( i in seq(1,length(type),1) ) {
	
	pval.list = c()
	
	for ( j in seq(1,length(type),1) ){
		p <- t.test(d[d$condition==type[i], ]$Norm.fold, d[d$condition==type[j], ]$Norm.fold, alternative="greater")
		
		pval.list <- c(pval.list, p$p.value)
	}
	
	pval <- rbind( pval, pval.list) 
}
x.lab=type
colnames(pval) <- x.lab
rownames(pval) <- x.lab

write.table(pval, file=paste0("Cscore_experiment/RelConf_pval_FAM50A-FAM50B_",cell,".csv"),sep=",",col.names=NA)


data <- data.frame()
r1 <- data.frame(type="Control", mean=mean(d[d$condition=="Control", ]$Norm.fold), sd=sd(d[d$condition=="Control", ]$Norm.fold) )
r2 <- data.frame(type="FAM50A", mean=mean(d[d$condition=="FAM50A", ]$Norm.fold), sd=sd(d[d$condition=="FAM50A", ]$Norm.fold) )
r3 <- data.frame(type="FAM50B", mean=mean(d[d$condition=="FAM50B", ]$Norm.fold), sd=sd(d[d$condition=="FAM50B", ]$Norm.fold) )
r4 <- data.frame(type="FAM50A+FAM50B", mean=mean(d[d$condition=="FAM50A+FAM50B", ]$Norm.fold), sd=sd(d[d$condition=="FAM50A+FAM50B", ]$Norm.fold) )

data<-rbind(data, r1, r2, r3, r4)

data$type.reorder <- factor( data$type, c( "Control", "FAM50A", "FAM50B", "FAM50A+FAM50B") )

fig<- ggplot(data, aes(x=type.reorder, y=mean)) +
	geom_bar(stat="identity") +
	geom_errorbar(aes(ymin=mean-sd, ymax=mean+sd), width =0.5, position=position_dodge(0.9)) + 
	scale_y_continuous(expand=c(0,0), limits=c(0,1.1))+
	labs(x=NULL, y="Relative cell growth", title=cell) +
	theme(panel.background = element_blank(), axis.line = element_line(colour = "black"),
							axis.text=element_text(size=20), text=element_text(size=25, color="black") ) 

fig
ggsave(filename=paste0("Cscore_experiment/RelConf_FAM50A-FAM50B_96hr_",cell,".mod.barplot.svg"), plot=fig, device="svg", height=7, width=5)