###
### Calculate C-score
###

import argparse
import pandas as pd
import numpy as np
import pingouin as pg
import sys

class pkg():

    def __init__(self, args={}):
        "initialization by adding all arguments to self"
        self.args = {}
        self.args.update(args)
        self.vars = {}
    
        if self.args['cnv']:
            self.pcor = True
        else:
            self.pcor = False


    def main(self):
        #print(start, end)
        print('reading dep...')
        dep = pd.read_pickle(self.args['dep'])

        print('reading exp...')
        exp = pd.read_pickle(self.args['exp'])

        if self.pcor:
            print('reading cnv...')
            cnv = pd.read_pickle(self.args['cnv'])

        if self.args['wt']:
            wt = pd.read_pickle(self.args['wt'])

        print('interseting...')
        ind = dep.index.intersection(exp.index)
        col = dep.columns.intersection(exp.columns)
        if self.pcor:
            ind = ind.intersection(cnv.index)
            col = col.intersection(cnv.columns)
        if self.args['wt']:
            ind = ind.intersection(wt.index)
            col = col.intersection(wt.columns)


        print('reindexing...')   
        dep = dep.reindex(index=ind, columns=col)
        exp = exp.reindex(index=ind, columns=col)
        if self.pcor:
            cnv = cnv.reindex(index=ind, columns=col)
        if self.args['wt']:
            wt = wt.reindex(index=ind, columns=col)

        #dep_slicedCol = dep.columns[start:end]


        print(dep.shape)
        
        print("calculating correlation...")
        droplist = []
        for i in dep_slicedCol:
            for j in exp.columns:
                cpair = pd.DataFrame({'dep':dep[i], 'exp':exp[j]})
                try:
                    if self.args['wt']:
                        cpair['g1_wt'] = wt[i];
                        cpair['g2_wt'] = wt[j];
                        cpair = cpair[(cpair['g1_wt'] != 0) & (cpair['g2_wt'] != 0)]
                    if self.pcor:
                        cpair['cnv'] = cnv[j]
                        cpair.dropna(axis=0, how='any', inplace=True)
                        cor_temp = pg.partial_corr(data=cpair, x='dep', y='exp', covar='cnv')
                    else:
                        cor_temp = cpair.loc[:,['dep','exp']].corr()
                    cor.at[i,j] = cor_temp.iloc[0][1]
                except:
                    sys.stderr.write('exception: '+j)
                    droplist.append(j)
                    continue
        cor.drop(columns=droplist, inplace=True)
        print(cor)
        cor.to_pickle(self.args['out'])
 
        start = self.args['start']
        end = self.args['end']
        out = self.args['out']

        print(start, end)

        print('reading cor...')
 
        cor = pd.read_pickle(self.args['cor'])

        col = sorted(cor.index.intersection(col))

        print('reindexing...')   
        cor = cor.reindex(index=col, columns=col)
        
        dep = dep.reindex(columns=col)
        exp = exp.reindex(columns=col)

        #print('subsetting...')
        #cor = cor[start:end]

        print('calculating slope...')

        slope = cor / dep.std()
        slope = slope.T

        for i in slope.index:
            print(i)
            idx = dep.index[~dep.loc[:,i].isnull()]
            slope.loc[i,:] = slope.loc[i,:] * exp.loc[idx,:].std()
        print(slope)

        if self.args['wt']:
            slope_filename = 'slope_wt_' + out + '.pkl'
        else:
            slope_filename = 'slope_' + out + '.pkl'

        slope.to_pickle(slope_filename)

        print( 'removing columns with low exp')

        for i in slope.columns:
            slope[i] = slope[i].apply(lambda x : np.nan if abs(x) < 0.00748 else x)

        print( 'calculating cscore')

        slmin = 0.00748
        c = cor*(1+slmin/slope.T)
        print(c)

        if self.args['wt']:
            c_filename = 'c_wt_' + out + '.pkl'
        else:
            c_filename = 'c_' + out + '.pkl'

        c.to_pickle(c_filename)


if __name__ == "__main__":
    parser = argparse.ArgumentParser()

    parser.add_argument('-cor', required=True)
    parser.add_argument('-dep', required=True)
    parser.add_argument('-exp', required=True)
    parser.add_argument('-wt', required=False, help='mutation file, if enetered, the the script will calculate cscore only for WT genes')
    parser.add_argument('-cnv', required=False, help='cnv file, if entered, then the script wil calculate partial correlation controlling for copy number')
    parser.add_argument('-start', type=int, required=False, help='starting positoin for splitting files')
    parser.add_argument('-end', type=int, required=False, help='ending position for splitting files')
    parser.add_argument('-out', required=True)
    
    args = parser.parse_args()

    a=pkg(vars(args))
    a.main()
