library(ggplot2)

d <- read.table('Cscore_wt/ONG_TSG_0.25_matched_correlation_list.txt',header=T, sep='\t')

d_cancer = d[d$cancer_gene == 1,]
d_noncan = d[d$cancer_gene == 0,]

d_cor = cor.test(d_noncan$c, d_noncan$c_wt)

can_corlist = c()
non_corlist = c()

pcan_corlist = c()
pnon_corlist = c()

for( r in seq(0.25, 0.50, 0.05) ) {
	d_cancer = d[d$onco_pot < 0.05 & d$c > r, ]
	d_noncan = d[d$onco_pot >= 0.05 & d$c > r,]

	can_cor = cor.test(d_cancer$c, d_cancer$c_wt)
	non_cor = cor.test(d_noncan$c, d_noncan$c_wt)

	can_corlist = c(can_corlist, can_cor$estimate)
	non_corlist = c(non_corlist, non_cor$estimate)
	
	pcan_corlist = c(can_corlist, can_cor$p.value)
	pnon_corlist = c(non_corlist, non_cor$p.value)
}

cor.df = data.frame(cscore=seq(0.25, 0.50, 0.05), can=can_corlist, non=non_corlist)

ggplot(cor.df) +
	geom_line(aes(x=cscore, y=can), color="dodgerblue", size=1 ) +
	geom_line(aes(x=cscore, y=non), color="black", size=1 ) +
	geom_point(aes(x=cscore, y=can), color="dodgerblue", size=3) +
	geom_point(aes(x=cscore, y=non), color="black", size=3) +
	scale_y_continuous(limits=c(0.8,1)) +
	labs(x="C-score cutoff", y="Correlation between C-score and WT C-score") +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position="none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
	

fig<-ggplot(d, aes(c, c_wt, color=as.factor(cancer_gene))) +
	geom_point() +
	scale_color_manual(values=c("black","dodgerblue"))+
	scale_x_continuous(limits=c(0,0.8), breaks=seq(0,0.8,0.2)) +
	scale_y_continuous(limits=c(0,0.8), breaks=seq(0,0.8,0.2)) +
	labs(x="C-score", y="C-score WT", title=paste("non-cancer cor", round(d_cor$estimate,3), "; p-val: ", d_cor$p.value)) +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position="none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
fig
ggsave( "D:/Cscore/Cscore_wt/Cscore_wt_cor_oncopot.png", fig, device='png', height=7, width=7)




prop = data.frame(class=c("wt.mean", "mt.mean"), means=c(673.1501976284585, 15.8498023715415), sd=c(15.449665066081923,15.449665066081923))
prop$class = reorder(prop$class, -prop$means)
fig<-ggplot(prop, aes(x=class, y=means)) +
	geom_col() +
	geom_errorbar(aes(ymin=means-sd, ymax=means+sd), width=0.5, size=1) +
	scale_x_discrete(labels=c("WT", "MT")) +
	labs(x="none", y="Average number of cell lines") +
	theme( panel.background = element_blank(), axis.line = element_line(colour = "grey50"), legend.position="none", axis.text=element_text(size=20, color="black"), text=element_text(size=25) )
fig
ggsave( "D:/Cscore/Cscore_wt/Cscore_wt_proportion.svg", fig, device='svg', height=7, width=7)

								