library(ggplot2)

data <- read.table("Cscore_survivalAUC/survival_auc.txt", header=T, sep="\t")

myCol <- rep(c("#FEC905","#F7EB5B", "#EB5E1D", "#E41513", "#78170E", "#432918"), 18 )



fig <- ggplot(data, aes(x=reorder(Cancer, -AUC, FUN=mean ), y=AUC ) ) +
	geom_dotplot(binaxis='y', stackdir='center', dotsize=0.7, fill=myCol, color=NA) +
	geom_hline( yintercept = 0.5, linetype='dashed', color='grey30') +
	labs( x=NULL, y="Area under curve" ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"),legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black"),
								axis.text.x=element_text( angle=90, vjust=0.5, hjust=1))
fig
ggsave( "D:/Cscore/Cscore_survivalAUC/Cscore_survivalAUC_allCscores.svg", fig, device='svg', height=7, width=13)

data25 <- data[data$Cscore == 0.25,  ]
data35 <- data[data$Cscore == 0.35,  ]

data = data[data$Significance == 1, ]
myCol <- c("#F7EB5B", "#FEC905", "#EB5E1D", "#E41513", "#78170E", "#432918"  )
fig<-ggplot(data, aes( x=reorder(Cancer,-AUC,mean), y=AUC-0.5, fill=as.factor(Cscore) ) ) +
	geom_bar(stat="identity", position=position_dodge2(reverse=TRUE) ) +
	geom_hline( yintercept = 0, linetype='dashed', color='grey30') +
	scale_y_continuous( limits=c(-0.1,0.125), breaks=seq(-0.1,0.125,0.025), label=seq(0.4,0.625,0.025) ) +
	scale_fill_manual(values=myCol) + 
	labs( x=NULL, y="Area under curve" ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"),legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black"),
								axis.text.x=element_text( angle=90, vjust=0.5, hjust=1))
fig
ggsave( "D:/Cscore/Cscore_survivalAUC/Cscore_survivalAUC_allBar.svg", fig, device='svg', height=7, width=11)


### Suvival AUC
data <- read.table("Cscore_survivalAUC/20210111_survival_auc.txt", header=T, sep="\t")
myCol <- c("#F7EB5B", "#FEC905", "#EB5E1D", "#E41513", "#78170E", "#432918"  )
data$Cancer <- factor(data$Cancer, c('PAAD','MESO','SARC','LAML','KIRP','PCPG','OV','LGG', 'GBM', 'KIRC'))
fig<-ggplot(data, aes( x=Cancer, y=AUC-0.5, fill=as.factor(Cscore) ) ) +
	geom_bar(stat="identity", position=position_dodge2(reverse=TRUE) ) +
	geom_hline( yintercept = 0, linetype='dashed', color='grey30') +
	scale_y_continuous( limits=c(-0.05,0.4), breaks=seq(-0.05,0.4,0.05), label=seq(0.45,0.9,0.05) ) +
	scale_fill_manual(values=myCol) + 
	labs( title='Survival AUC', x=NULL, y="Area under curve" ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"),legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black"),
								axis.text.x=element_text( angle=90, vjust=0.5, hjust=1), plot.title=element_text(size=25))
fig
ggsave( "D:/Cscore/Cscore_survivalAUC/Cscore_survivalAUC_allBar.new.svg", fig, device='svg', height=7, width=11)



### Pathology AUC
data <- read.table("Cscore_survivalAUC/20210215_survival_auc_pathology.txt", header=T, sep="\t")
myCol <- c("#F7EB5B", "#FEC905", "#EB5E1D", "#E41513", "#78170E", "#432918"  )
data$Cancer <- factor(data$Cancer, c('PAAD','COAD','THCA','KIRP','KIRC','ESCA','BLCA'))
fig<-ggplot(data, aes( x=Cancer, y=AUC-0.5, fill=as.factor(Cscore) ) ) +
	geom_bar(stat="identity", position=position_dodge2(reverse=TRUE) ) +
	geom_hline( yintercept = 0, linetype='dashed', color='grey30') +
	scale_y_continuous( limits=c(-0.15,0.4), breaks=seq(-0.15,0.4,0.05), label=seq(0.35,0.9,0.05) ) +
	scale_fill_manual(values=myCol) + 
	labs( title='Pathology stage AUC',  x=NULL, y="Area under curve" ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"),legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black"),
								axis.text.x=element_text( angle=90, vjust=0.5, hjust=1), plot.title=element_text(size=25))
fig
ggsave( "D:/Cscore/Cscore_survivalAUC/Cscore_survival_pathology_auc.allBar.svg", fig, device='svg', height=7, width=11)

### Clinical AUC
data <- read.table("Cscore_survivalAUC/20210215_survival_auc_clinical.txt", header=T, sep="\t")
myCol <- c("#F7EB5B", "#FEC905", "#EB5E1D", "#E41513", "#78170E", "#432918"  )
data$Cancer <- factor(data$Cancer, c('UCEC','OV','CESC', 'KIRP'))
fig<-ggplot(data, aes( x=reorder(Cancer,-AUC,mean), y=AUC-0.5, fill=as.factor(Cscore) ) ) +
	geom_bar(stat="identity", position=position_dodge2(reverse=TRUE) ) +
	geom_hline( yintercept = 0, linetype='dashed', color='grey30') +
	scale_y_continuous( limits=c(-0.15,0.4), breaks=seq(-0.15,0.4,0.05), label=seq(0.35,0.9,0.05) ) +
	scale_fill_manual(values=myCol) + 
	labs( title='Clinical stage AUC',  x=NULL, y="Area under curve" ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"),legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black"),
								axis.text.x=element_text( angle=90, vjust=0.5, hjust=1), plot.title=element_text(size=25))
fig
ggsave( "D:/Cscore/Cscore_survivalAUC/Cscore_survival_clinical_auc.allBar.svg", fig, device='svg', height=7, width=11)

### Grade AUC
data <- read.table("Cscore_survivalAUC/20210215_survival_auc_grade.txt", header=T, sep="\t")
myCol <- c("#F7EB5B", "#FEC905", "#EB5E1D", "#E41513", "#78170E", "#432918"  )
data$Cancer <- factor(data$Cancer, c('UCEC','ESCA','PAAD', 'KIRC'))
fig<-ggplot(data, aes( x=reorder(Cancer,-AUC,mean), y=AUC-0.5, fill=as.factor(Cscore) ) ) +
	geom_bar(stat="identity", position=position_dodge2(reverse=TRUE) ) +
	geom_hline( yintercept = 0, linetype='dashed', color='grey30') +
	scale_y_continuous( limits=c(-0.15,0.4), breaks=seq(-0.15,0.4,0.05), label=seq(0.35,0.9,0.05) ) +
	scale_fill_manual(values=myCol) + 
	labs( title='Grade AUC',  x=NULL, y="Area under curve" ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"),legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black"),
								axis.text.x=element_text( angle=90, vjust=0.5, hjust=1), plot.title=element_text(size=25))
fig
ggsave( "D:/Cscore/Cscore_survivalAUC/Cscore_survival_grade_auc.allBar.svg", fig, device='svg', height=7, width=11)

