library(ggplot2)
library(dplyr)


data <- read.table("Cscore_SLmean/sl_mean_tissue_numCellline.csv", header=T, sep=",")

data = data[data$num_celllines > 5, ]

fig<-ggplot(data, aes( x=reorder(X,sl_mean ), y= -1*sl_mean ) ) +
	geom_bar(stat="identity" ) +
	scale_y_continuous( expand=c(0,0), limits=c(0,1.3)) +
	labs( x=NULL, y="Mean of buffering score" ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"),legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black"),
								axis.text.x=element_text( angle=90, vjust=0.5, hjust=1))
fig
ggsave( "D:/Cscore/Cscore_SLmean/Cscore_BufferingMean.bar.svg", fig, device='svg', height=9, width=11)




d <- read.table("cscore_1sd_info.protInt.disease.Tau.csv", header=T, sep=',')


g1 = d$G1_tissue_tau
g2 = d$G2_tissue_tau
r  = d$G2_tau_rand1 

d.box <- data.frame(feature=g1, group=rep("G1", times=length(g1)))
d.box <- rbind( d.box, data.frame(feature=g2, group=rep("G2", times=length(g2))))

p1 <- t.test(x=g1, y=g2, alternative="less", paired=T)

fig<-ggplot(d.box, aes(x=group, y=feature, fill=group)) +
	stat_ydensity( color=NA, alpha=0.25,adjust=3, trim=T) +
	geom_boxplot( width=0.1,outlier.shape=NA ) +
	labs( x=NULL, y='Tissue Specificity', title=paste("G1 v G2 paired-t p-value:",signif(p1$p.value,3)) ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"), legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black") )
fig
ggsave( filename='Cscore_tissue_spec/g1g2_disease_tau.violin.svg', plot=fig, device="svg", height=7, width=10 )

d.box <- data.frame(feature=g2, group=rep("G2", times=length(g2)))
d.box <- rbind( d.box, data.frame(feature=r, group=rep("G2 rand tau", times=length(r))))

p1 <- t.test(x=g2, y=r, alternative="greater", paired=T)

fig<-ggplot(d.box, aes(x=group, y=feature, fill=group)) +
	stat_ydensity( color=NA, alpha=0.25,adjust=3, trim=T) +
	geom_boxplot( width=0.1,outlier.shape=NA ) +
	#scale_y_continuous(limits=c(0,600)) +
	labs( x=NULL, y='Tissue Specificity', title=paste("G2 v G2rand paired-t p-value:",signif(p1$p.value,3)) ) +
	theme( panel.background = element_blank(), axis.line = element_line(color="black"), legend.position = "none",
								axis.text=element_text(size=20, color="black"), axis.title=element_text(size=25, color="black") )
fig
ggsave( filename='Cscore_tissue_spec/g1g2_disease_tau.G2rand.violin.svg', plot=fig, device="svg", height=7, width=10 )