#
#   Calculate tissue-specificity based on cell lineages
#

import pandas as pd
import numpy as np
import argparse

def main(args):
    args = parser.parse_args()

    sample_file = args.sample_info
    colname = args.col
    exp_file = args.exp
    outfile = args.out

    sample = pd.read_csv(sample_file, index_col=0)
    
    exp = pd.read_pickle(exp_file)

    exp[exp<1] = 0

    tissue = sample[colname]
    tissue = tissue.reindex(index=tissue.index.intersection(tissue.index))
    
    tissue_exp = pd.DataFrame(columns=exp.columns)

#    print(exp)

    print(tissue.unique())

    for i in tissue.unique():
        curr_tissue = tissue[tissue==i]

        subset_tissue_exp = exp.reindex(index=curr_tissue.index)

        mean_subset_tissue_exp = subset_tissue_exp.mean(axis=0, skipna=True).to_frame(name=i).T

        tissue_exp = tissue_exp.append(mean_subset_tissue_exp)

   
    print(tissue_exp)

    max_exp = tissue_exp.max()
    print(max_exp)

    tau = pd.DataFrame(index=tissue_exp.columns, columns=['tau'])
    tau.index.name = 'Gene'

    for i in tissue_exp.columns:
        tau.at[i, 'tau'] = ((1-tissue_exp[i]/max_exp[i]).sum()/(len(tissue_exp.index)-1))

    print(tau)
    
    tau.to_csv(outfile)
    




if __name__ == "__main__":
    parser = argparse.ArgumentParser()

    parser.add_argument('-sample', '--sample_info', required=True)
    parser.add_argument('-col', required=True)
    parser.add_argument('-exp', required=True)
    parser.add_argument('-dep', required=False)
    parser.add_argument('-out', required=True)

    main(parser.parse_args())
