#!/usr/bin/perl
#
#	Compile DS mean/sd and Expr mean/sd of paralogs
#	Input:	Achilles_gene_effect.csv (hard link)
#			CCLE_expression.csv (hard link)
#	Output: gene_ds_expr.compile.txt
#

use strict;
use Getopt::Long;
#use File::Basename;

#use lib qw( /home2/test12/JenHao/code/module );
use lib qw( /mnt/home/jenhao/Research/code/module );
use MyStats;

my ( $dep_file, $exp_file, $c_file, $para_file, $tau_file, $ppi_file, $age_file, $outfile );

my $usage = "\n" . "Usage:\n\tperl " . $0 . "-dep Archilles_gene_effect.formatExp.csv -exp CCEL_expression.formatDep.csv -cscore all_v_all_cscore_b1.csv -pNum ensembl_paralog_all.txt -tau Tau_DepMap_19Q4/CCLE_expression_v19Q4_tau.pl -ppi STRINGv11_PPI_highConf.txtl -age geneAge_info.txt -out geneds_expr.compile.txt ";

GetOptions(
	'dep|dep_file=s'	=> \$dep_file,
	'exp|exp_file=s'	=> \$exp_file,
	'c|cscore|c_file=s'	=> \$c_file,
	'pNum|para_file=s'	=> \$para_file,
	'tau|tau_file=s'	=> \$tau_file,
	'ppi|ppi_file=s'	=> \$ppi_file,
	'age|age_file=s'	=> \$age_file,
	'o|out|outfile=s'   => \$outfile,
) or die $usage;

my %data;

print STDERR "loading dependency score file ...";

my $tmp_dep_data = loadDepMapFile( $dep_file, "dep", \%data );
%data = %{$tmp_dep_data};

print STDERR "Done\n";
print STDERR "loading expression file ...";

my $tmp_exp_data = loadDepMapFile( $exp_file, "exp", \%data );
%data = %{$tmp_exp_data};

print STDERR "Done\n";
print STDERR "loading cscore file ...";

my $tmp_cscore = loadCscore( $c_file );
my %cscore = %{$tmp_cscore};

print STDERR "Done\n";
print STDERR "loading ensembl paralog file ...";

my $tmp_pNum = loadPNum( $para_file );
my %pNum = %{$tmp_pNum};

print STDERR "Done\n";
print STDERR "loading tissue specificity file ...";

my $tmp_tau = loadTau( $tau_file );
my %tau = %{$tmp_tau};

print STDERR "Done\n";
print STDERR "loading ppi file ...";

my $tmp_ppi = loadPPI( $ppi_file );
my %ppi = %{$tmp_ppi};

my $tmp_age = loadAge( $age_file );
my %age = %{$tmp_age};

print STDERR "Done\n";

open( OUT, ">$outfile" ) or die "Can't write to $outfile";

print OUT "Gene\tDS_mean\tDS_sd\tExpr_mean\tExpr_sd\tPearson\tCscore\tParalog_num\tTau\tPPI\n";

foreach my $gene ( keys %data ) {
	
	my ( @dep, @exp, @exp_noMatch, @exp_match );
	foreach my $cell ( sort keys %{$data{$gene}} ) {
		if ( exists $data{$gene}{$cell}{dep} and exists $data{$gene}{$cell}{exp} ) {
			push( @dep, $data{$gene}{$cell}{dep} );
			push( @exp, $data{$gene}{$cell}{exp} );
			push( @exp_match, $data{$gene}{$cell}{exp} ) if ($gene eq "XG");
		} else {
			print STDERR "cell line unmatched\n";
		}
		push( @exp_noMatch, $data{$gene}{$cell}{exp} ) if ( $gene eq "XG");
	}

	if ( scalar(@dep) < 1 ) {
		next;
	}

	my ( $dep_mean, $dep_sd ) = MyStats::MeanStdDev( \@dep );
	my ( $exp_mean, $exp_sd ) = MyStats::MeanStdDev( \@exp );
#	my ( $pearson ) = MyStats::Pearson( \@dep, \@exp );

	if ( $gene eq "XG" ) {
		my ( $exp_mean_noMatch, $exp_sd ) = MyStats::MeanStdDev( \@exp_noMatch );
		print STDERR "exp_match\t".$exp_mean."\n";
		print STDERR "exp_noMatch\t".$exp_mean_noMatch."\n";

		open( ONE, ">testCellMatched" );
		print ONE join("\n", @exp_match)."\n";
		close ONE;

		open( TWO, ">testCellUnmatched" );
		print TWO join("\n", @exp_noMatch)."\n";
		close TWO;

	}

	if ( exists $cscore{$gene} == 0 or $exp_mean < 0.5 ) {
		$cscore{$gene} = "NA";
	}

	if ( exists $pNum{$gene} == 0 ) {
		$pNum{$gene} = 0;
	}
	
	if ( exists $tau{$gene} == 0 ) {
		$tau{$gene} = "NA";
	}
	
	if ( exists $ppi{$gene} == 0 ) {
		$ppi{$gene} = "NA";
	}

	if ( exists $age{$gene} == 0 ) {
		$age{$gene} = "NA";
	}

	my @println = ( $gene, $dep_mean, $dep_sd, $exp_mean, $exp_sd, $pearson, $cscore{$gene}, $pNum{$gene}, $tau{$gene}, $ppi{$gene} );
#	my @println = ( $gene, $dep_mean, $dep_sd, $exp_mean, $exp_sd );
	print OUT join( "\t", @println )."\n";
}

close OUT;

###########################################################

sub loadAge {
	my $age_file = shift;
	my $type     = shift;

	$type =~ s/^txt$/text/g;
	$type =~ s/^numeric$/num/g;

	if ( !defined $type ) {
		$type = "text";
	} elsif ( $type ne "text" and $type ne "num" ) {
		die "Age type incorrect: $type. Should be \"text\" or \"num\"\n";
	}

	my %age;
	open( AGE, $age_file ) or die "Can't open $age_file";
	<AGE>;
	while( <AGE> ) {
		$_ =~ s/^\s+|\s+$//g;

		my @line = split "\t", $_;

		my $gene = $line[0];
		my $modeAge;
		if ( $type = "text" ) {
			$modeAge = $line[1];
		} else {
			$modeAge = $line[2];
		}

		$age{$gene} = $modeAge;
	}
	close AGE;

	return \%age;
}


sub loadPPI { 
	my $ppi_file = shift;

	my %ppi;

	open( PPI, $ppi_file ) or die "Can't open $ppi_file";
	<PPI>;
	while( <PPI> ) {
		$_ =~ s/^\s+|\s+$//g;

		my @line = split "\t", $_;

		$ppi{$line[0]} = $line[2];
	}
	close PPI;

	return \%ppi;
}

sub loadTau { 
	my $tau_file = shift;

	my %tau;

	open( TAU, $tau_file ) or die "Can't open $tau_file";
	<TAU>;
	while( <TAU> ) {
		$_ =~ s/^\s+|\s+$//g;

		my @line = split "\t", $_;

		$tau{$line[0]} = $line[1];
	}
	close TAU;

	return \%tau;
}

sub loadCscore {
	my $file = shift;

	my %cscore;

	open( FILE, $file ) or die "Can't open $file";
	<FILE>;
	while( <FILE> ) {
		$_ =~ s/^\s+|\s+$//g;

		my @line = split ",", $_;

		my $g1 = $line[0];

		$cscore{$g1} = $line[$.-1];
	}
	close FILE;

	return \%cscore;
}


sub loadPNum {
	my $file = shift;

	my %pnum;

	open( FILE, $file ) or die "Can't open $file";
	<FILE>;
	while( <FILE> ) {
		$_ =~ s/^\s+|\s+$//g;

		my @line = split "\t", $_;

		my $gene = $line[0];
		my $para = $line[2];

		if ( length($para) > 0 ) {
			if ( exists $pnum{$gene} ) {
				$pnum{$gene} = $pnum{$gene} + 1;
			} else {
				$pnum{$gene} = 1;
			}
		}
	}
	close FILE;

	return \%pnum;
}


sub loadDepMapFile {
	my $file_path = shift;
	my $data_type = shift;
	my $tmp_data  = shift;
	
	my %data = %{$tmp_data};

	if ( $data_type ne "dep" and $data_type ne "exp" ) {
		print STDERR "[ERROR] Loading DepMap File - Data type does not match: ".$data_type."\n";
	}

	open( FILE, $file_path ) or die "Can't open $file_path";
	my $head = <FILE>;
	$head =~ s/^\s+|\s+$//g;

	my @header = split ",", $head;

	while( <FILE> ) {
		$_ =~ s/^\s+|\s+$//g;

		my @line = split ",", $_;

		my $cell = $line[0];

		for( my $i = 1; $i < @line; $i++ ) {

			my $gene_symbol = $header[$i];
			if ( $header[$i] =~ /(.+) \(\d+\)$/ ) {
				$gene_symbol = $1;
			}

			if ( $line[$i] ne "NA" ) {
				$data{$gene_symbol}{$cell}{$data_type} = $line[$i];
			}
		}
	}
	close FILE;

	return \%data;
}
